==> chaosmesh-model-5.7.4-sources.jar: io/fabric8/chaosmesh/v1alpha1/ExperimentStatusFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class ExperimentStatusFluentImpl<A extends io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluent<A>{
  public ExperimentStatusFluentImpl() {
  }
  public ExperimentStatusFluentImpl(io.fabric8.chaosmesh.v1alpha1.ExperimentStatus instance) {
    this.withDuration(instance.getDuration()); 
    this.withEndTime(instance.getEndTime()); 
    this.withPhase(instance.getPhase()); 
    this.withPodRecords(instance.getPodRecords()); 
    this.withReason(instance.getReason()); 
    this.withStartTime(instance.getStartTime()); 
  }
  private java.lang.String duration;
  private java.lang.String endTime;
  private java.lang.String phase;
  private java.util.List<io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder> podRecords;
  private java.lang.String reason;
  private java.lang.String startTime;
  public java.lang.String getDuration() {
    return this.duration;
  }
  public A withDuration(java.lang.String duration) {
    this.duration=duration; return (A) this;
  }
  public java.lang.Boolean hasDuration() {
    return this.duration != null;
  }
  
  /**
   * Method is deprecated. use withDuration instead.
   */
  @java.lang.Deprecated
  public A withNewDuration(java.lang.String arg0) {
    return (A)withDuration(new String(arg0));
  }
  public java.lang.String getEndTime() {
    return this.endTime;
  }
  public A withEndTime(java.lang.String endTime) {
    this.endTime=endTime; return (A) this;
  }
  public java.lang.Boolean hasEndTime() {
    return this.endTime != null;
  }
  
  /**
   * Method is deprecated. use withEndTime instead.
   */
  @java.lang.Deprecated
  public A withNewEndTime(java.lang.String arg0) {
    return (A)withEndTime(new String(arg0));
  }
  public java.lang.String getPhase() {
    return this.phase;
  }
  public A withPhase(java.lang.String phase) {
    this.phase=phase; return (A) this;
  }
  public java.lang.Boolean hasPhase() {
    return this.phase != null;
  }
  
  /**
   * Method is deprecated. use withPhase instead.
   */
  @java.lang.Deprecated
  public A withNewPhase(java.lang.String arg0) {
    return (A)withPhase(new String(arg0));
  }
  public A addToPodRecords(java.lang.Integer index,io.fabric8.chaosmesh.v1alpha1.PodStatus item) {
    if (this.podRecords == null) {this.podRecords = new java.util.ArrayList<io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder>();}
    io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder builder = new io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder(item);_visitables.get("podRecords").add(index >= 0 ? index : _visitables.get("podRecords").size(), builder);this.podRecords.add(index >= 0 ? index : podRecords.size(), builder); return (A)this;
  }
  public A setToPodRecords(java.lang.Integer index,io.fabric8.chaosmesh.v1alpha1.PodStatus item) {
    if (this.podRecords == null) {this.podRecords = new java.util.ArrayList<io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder>();}
    io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder builder = new io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder(item);
    if (index < 0 || index >= _visitables.get("podRecords").size()) { _visitables.get("podRecords").add(builder); } else { _visitables.get("podRecords").set(index, builder);}
    if (index < 0 || index >= podRecords.size()) { podRecords.add(builder); } else { podRecords.set(index, builder);}
     return (A)this;
  }
  public A addToPodRecords(io.fabric8.chaosmesh.v1alpha1.PodStatus... items) {
    if (this.podRecords == null) {this.podRecords = new java.util.ArrayList<io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder>();}
    for (io.fabric8.chaosmesh.v1alpha1.PodStatus item : items) {io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder builder = new io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder(item);_visitables.get("podRecords").add(builder);this.podRecords.add(builder);} return (A)this;
  }
  public A addAllToPodRecords(java.util.Collection<io.fabric8.chaosmesh.v1alpha1.PodStatus> items) {
    if (this.podRecords == null) {this.podRecords = new java.util.ArrayList<io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder>();}
    for (io.fabric8.chaosmesh.v1alpha1.PodStatus item : items) {io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder builder = new io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder(item);_visitables.get("podRecords").add(builder);this.podRecords.add(builder);} return (A)this;
  }
  public A removeFromPodRecords(io.fabric8.chaosmesh.v1alpha1.PodStatus... items) {
    for (io.fabric8.chaosmesh.v1alpha1.PodStatus item : items) {io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder builder = new io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder(item);_visitables.get("podRecords").remove(builder);if (this.podRecords != null) {this.podRecords.remove(builder);}} return (A)this;
  }
  public A removeAllFromPodRecords(java.util.Collection<io.fabric8.chaosmesh.v1alpha1.PodStatus> items) {
    for (io.fabric8.chaosmesh.v1alpha1.PodStatus item : items) {io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder builder = new io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder(item);_visitables.get("podRecords").remove(builder);if (this.podRecords != null) {this.podRecords.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromPodRecords(java.util.function.Predicate<io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder> predicate) {
    if (podRecords == null) return (A) this;
    final Iterator<io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder> each = podRecords.iterator();
    final List visitables = _visitables.get("podRecords");
    while (each.hasNext()) {
      io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildPodRecords instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.chaosmesh.v1alpha1.PodStatus> getPodRecords() {
    return build(podRecords);
  }
  public java.util.List<io.fabric8.chaosmesh.v1alpha1.PodStatus> buildPodRecords() {
    return build(podRecords);
  }
  public io.fabric8.chaosmesh.v1alpha1.PodStatus buildPodRecord(java.lang.Integer index) {
    return this.podRecords.get(index).build();
  }
  public io.fabric8.chaosmesh.v1alpha1.PodStatus buildFirstPodRecord() {
    return this.podRecords.get(0).build();
  }
  public io.fabric8.chaosmesh.v1alpha1.PodStatus buildLastPodRecord() {
    return this.podRecords.get(podRecords.size() - 1).build();
  }
  public io.fabric8.chaosmesh.v1alpha1.PodStatus buildMatchingPodRecord(java.util.function.Predicate<io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder> predicate) {
    for (io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder item: podRecords) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingPodRecord(java.util.function.Predicate<io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder> predicate) {
    for (io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder item: podRecords) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withPodRecords(java.util.List<io.fabric8.chaosmesh.v1alpha1.PodStatus> podRecords) {
    if (this.podRecords != null) { _visitables.get("podRecords").removeAll(this.podRecords);}
    if (podRecords != null) {this.podRecords = new java.util.ArrayList<io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder>(); for (io.fabric8.chaosmesh.v1alpha1.PodStatus item : podRecords){this.addToPodRecords(item);}} else { this.podRecords = null;} return (A) this;
  }
  public A withPodRecords(io.fabric8.chaosmesh.v1alpha1.PodStatus... podRecords) {
    if (this.podRecords != null) {this.podRecords.clear();}
    if (podRecords != null) {for (io.fabric8.chaosmesh.v1alpha1.PodStatus item :podRecords){ this.addToPodRecords(item);}} return (A) this;
  }
  public java.lang.Boolean hasPodRecords() {
    return podRecords != null && !podRecords.isEmpty();
  }
  public io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluent.PodRecordsNested<A> addNewPodRecord() {
    return new io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluentImpl.PodRecordsNestedImpl();
  }
  public io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluent.PodRecordsNested<A> addNewPodRecordLike(io.fabric8.chaosmesh.v1alpha1.PodStatus item) {
    return new io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluentImpl.PodRecordsNestedImpl(-1, item);
  }
  public io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluent.PodRecordsNested<A> setNewPodRecordLike(java.lang.Integer index,io.fabric8.chaosmesh.v1alpha1.PodStatus item) {
    return new io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluentImpl.PodRecordsNestedImpl(index, item);
  }
  public io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluent.PodRecordsNested<A> editPodRecord(java.lang.Integer index) {
    if (podRecords.size() <= index) throw new RuntimeException("Can't edit podRecords. Index exceeds size.");
    return setNewPodRecordLike(index, buildPodRecord(index));
  }
  public io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluent.PodRecordsNested<A> editFirstPodRecord() {
    if (podRecords.size() == 0) throw new RuntimeException("Can't edit first podRecords. The list is empty.");
    return setNewPodRecordLike(0, buildPodRecord(0));
  }
  public io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluent.PodRecordsNested<A> editLastPodRecord() {
    int index = podRecords.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last podRecords. The list is empty.");
    return setNewPodRecordLike(index, buildPodRecord(index));
  }
  public io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluent.PodRecordsNested<A> editMatchingPodRecord(java.util.function.Predicate<io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder> predicate) {
    int index = -1;
    for (int i=0;i<podRecords.size();i++) { 
    if (predicate.test(podRecords.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching podRecords. No match found.");
    return setNewPodRecordLike(index, buildPodRecord(index));
  }
  public java.lang.String getReason() {
    return this.reason;
  }
  public A withReason(java.lang.String reason) {
    this.reason=reason; return (A) this;
  }
  public java.lang.Boolean hasReason() {
    return this.reason != null;
  }
  
  /**
   * Method is deprecated. use withReason instead.
   */
  @java.lang.Deprecated
  public A withNewReason(java.lang.String arg0) {
    return (A)withReason(new String(arg0));
  }
  public java.lang.String getStartTime() {
    return this.startTime;
  }
  public A withStartTime(java.lang.String startTime) {
    this.startTime=startTime; return (A) this;
  }
  public java.lang.Boolean hasStartTime() {
    return this.startTime != null;
  }
  
  /**
   * Method is deprecated. use withStartTime instead.
   */
  @java.lang.Deprecated
  public A withNewStartTime(java.lang.String arg0) {
    return (A)withStartTime(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ExperimentStatusFluentImpl that = (ExperimentStatusFluentImpl) o;
    if (duration != null ? !duration.equals(that.duration) :that.duration != null) return false;
    if (endTime != null ? !endTime.equals(that.endTime) :that.endTime != null) return false;
    if (phase != null ? !phase.equals(that.phase) :that.phase != null) return false;
    if (podRecords != null ? !podRecords.equals(that.podRecords) :that.podRecords != null) return false;
    if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
    if (startTime != null ? !startTime.equals(that.startTime) :that.startTime != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(duration,  endTime,  phase,  podRecords,  reason,  startTime,  super.hashCode());
  }
  public class PodRecordsNestedImpl<N> extends io.fabric8.chaosmesh.v1alpha1.PodStatusFluentImpl<io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluent.PodRecordsNested<N>> implements io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluent.PodRecordsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PodRecordsNestedImpl(java.lang.Integer index,io.fabric8.chaosmesh.v1alpha1.PodStatus item) {
      this.index = index;
      this.builder = new io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder(this, item);
    }
    PodRecordsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder(this);
    }
    io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) ExperimentStatusFluentImpl.this.setToPodRecords(index,builder.build());
    }
    public N endPodRecord() {
      return and();
    }
    
  }
  
}

==> chaosmesh-model-5.12.1-sources.jar: io/fabric8/chaosmesh/v1alpha1/ExperimentStatusFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Integer;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.Iterator;
import java.util.Collection;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;

 /**
  * Generated
  */
public class ExperimentStatusFluentImpl<A extends io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluent<A>{
  public ExperimentStatusFluentImpl() {
  }
  public ExperimentStatusFluentImpl(io.fabric8.chaosmesh.v1alpha1.ExperimentStatus instance) {
    this.withDuration(instance.getDuration()); 
    this.withEndTime(instance.getEndTime()); 
    this.withPhase(instance.getPhase()); 
    this.withPodRecords(instance.getPodRecords()); 
    this.withReason(instance.getReason()); 
    this.withStartTime(instance.getStartTime()); 
  }
  private java.lang.String duration;
  private java.lang.String endTime;
  private java.lang.String phase;
  private java.util.List<io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder> podRecords;
  private java.lang.String reason;
  private java.lang.String startTime;
  public java.lang.String getDuration() {
    return this.duration;
  }
  public A withDuration(java.lang.String duration) {
    this.duration=duration; return (A) this;
  }
  public java.lang.Boolean hasDuration() {
    return this.duration != null;
  }
  
  /**
   * Method is deprecated. use withDuration instead.
   */
  @java.lang.Deprecated
  public A withNewDuration(java.lang.String arg0) {
    return (A)withDuration(new String(arg0));
  }
  public java.lang.String getEndTime() {
    return this.endTime;
  }
  public A withEndTime(java.lang.String endTime) {
    this.endTime=endTime; return (A) this;
  }
  public java.lang.Boolean hasEndTime() {
    return this.endTime != null;
  }
  
  /**
   * Method is deprecated. use withEndTime instead.
   */
  @java.lang.Deprecated
  public A withNewEndTime(java.lang.String arg0) {
    return (A)withEndTime(new String(arg0));
  }
  public java.lang.String getPhase() {
    return this.phase;
  }
  public A withPhase(java.lang.String phase) {
    this.phase=phase; return (A) this;
  }
  public java.lang.Boolean hasPhase() {
    return this.phase != null;
  }
  
  /**
   * Method is deprecated. use withPhase instead.
   */
  @java.lang.Deprecated
  public A withNewPhase(java.lang.String arg0) {
    return (A)withPhase(new String(arg0));
  }
  public A addToPodRecords(java.lang.Integer index,io.fabric8.chaosmesh.v1alpha1.PodStatus item) {
    if (this.podRecords == null) {this.podRecords = new java.util.ArrayList<io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder>();}
    io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder builder = new io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder(item);_visitables.get("podRecords").add(index >= 0 ? index : _visitables.get("podRecords").size(), builder);this.podRecords.add(index >= 0 ? index : podRecords.size(), builder); return (A)this;
  }
  public A setToPodRecords(java.lang.Integer index,io.fabric8.chaosmesh.v1alpha1.PodStatus item) {
    if (this.podRecords == null) {this.podRecords = new java.util.ArrayList<io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder>();}
    io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder builder = new io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder(item);
    if (index < 0 || index >= _visitables.get("podRecords").size()) { _visitables.get("podRecords").add(builder); } else { _visitables.get("podRecords").set(index, builder);}
    if (index < 0 || index >= podRecords.size()) { podRecords.add(builder); } else { podRecords.set(index, builder);}
     return (A)this;
  }
  public A addToPodRecords(io.fabric8.chaosmesh.v1alpha1.PodStatus... items) {
    if (this.podRecords == null) {this.podRecords = new java.util.ArrayList<io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder>();}
    for (io.fabric8.chaosmesh.v1alpha1.PodStatus item : items) {io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder builder = new io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder(item);_visitables.get("podRecords").add(builder);this.podRecords.add(builder);} return (A)this;
  }
  public A addAllToPodRecords(java.util.Collection<io.fabric8.chaosmesh.v1alpha1.PodStatus> items) {
    if (this.podRecords == null) {this.podRecords = new java.util.ArrayList<io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder>();}
    for (io.fabric8.chaosmesh.v1alpha1.PodStatus item : items) {io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder builder = new io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder(item);_visitables.get("podRecords").add(builder);this.podRecords.add(builder);} return (A)this;
  }
  public A removeFromPodRecords(io.fabric8.chaosmesh.v1alpha1.PodStatus... items) {
    for (io.fabric8.chaosmesh.v1alpha1.PodStatus item : items) {io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder builder = new io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder(item);_visitables.get("podRecords").remove(builder);if (this.podRecords != null) {this.podRecords.remove(builder);}} return (A)this;
  }
  public A removeAllFromPodRecords(java.util.Collection<io.fabric8.chaosmesh.v1alpha1.PodStatus> items) {
    for (io.fabric8.chaosmesh.v1alpha1.PodStatus item : items) {io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder builder = new io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder(item);_visitables.get("podRecords").remove(builder);if (this.podRecords != null) {this.podRecords.remove(builder);}} return (A)this;
  }
  public A removeMatchingFromPodRecords(java.util.function.Predicate<io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder> predicate) {
    if (podRecords == null) return (A) this;
    final Iterator<io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder> each = podRecords.iterator();
    final List visitables = _visitables.get("podRecords");
    while (each.hasNext()) {
      io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder builder = each.next();
      if (predicate.test(builder)) {
        visitables.remove(builder);
        each.remove();
      }
    }
    return (A)this;
  }
  
  /**
   * This method has been deprecated, please use method buildPodRecords instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.chaosmesh.v1alpha1.PodStatus> getPodRecords() {
    return build(podRecords);
  }
  public java.util.List<io.fabric8.chaosmesh.v1alpha1.PodStatus> buildPodRecords() {
    return build(podRecords);
  }
  public io.fabric8.chaosmesh.v1alpha1.PodStatus buildPodRecord(java.lang.Integer index) {
    return this.podRecords.get(index).build();
  }
  public io.fabric8.chaosmesh.v1alpha1.PodStatus buildFirstPodRecord() {
    return this.podRecords.get(0).build();
  }
  public io.fabric8.chaosmesh.v1alpha1.PodStatus buildLastPodRecord() {
    return this.podRecords.get(podRecords.size() - 1).build();
  }
  public io.fabric8.chaosmesh.v1alpha1.PodStatus buildMatchingPodRecord(java.util.function.Predicate<io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder> predicate) {
    for (io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder item: podRecords) { if(predicate.test(item)){ return item.build();} } return null;
  }
  public java.lang.Boolean hasMatchingPodRecord(java.util.function.Predicate<io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder> predicate) {
    for (io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder item: podRecords) { if(predicate.test(item)){ return true;} } return false;
  }
  public A withPodRecords(java.util.List<io.fabric8.chaosmesh.v1alpha1.PodStatus> podRecords) {
    if (this.podRecords != null) { _visitables.get("podRecords").removeAll(this.podRecords);}
    if (podRecords != null) {this.podRecords = new java.util.ArrayList(); for (io.fabric8.chaosmesh.v1alpha1.PodStatus item : podRecords){this.addToPodRecords(item);}} else { this.podRecords = null;} return (A) this;
  }
  public A withPodRecords(io.fabric8.chaosmesh.v1alpha1.PodStatus... podRecords) {
    if (this.podRecords != null) {this.podRecords.clear();}
    if (podRecords != null) {for (io.fabric8.chaosmesh.v1alpha1.PodStatus item :podRecords){ this.addToPodRecords(item);}} return (A) this;
  }
  public java.lang.Boolean hasPodRecords() {
    return podRecords != null && !podRecords.isEmpty();
  }
  public io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluent.PodRecordsNested<A> addNewPodRecord() {
    return new io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluentImpl.PodRecordsNestedImpl();
  }
  public io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluent.PodRecordsNested<A> addNewPodRecordLike(io.fabric8.chaosmesh.v1alpha1.PodStatus item) {
    return new io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluentImpl.PodRecordsNestedImpl(-1, item);
  }
  public io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluent.PodRecordsNested<A> setNewPodRecordLike(java.lang.Integer index,io.fabric8.chaosmesh.v1alpha1.PodStatus item) {
    return new io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluentImpl.PodRecordsNestedImpl(index, item);
  }
  public io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluent.PodRecordsNested<A> editPodRecord(java.lang.Integer index) {
    if (podRecords.size() <= index) throw new RuntimeException("Can't edit podRecords. Index exceeds size.");
    return setNewPodRecordLike(index, buildPodRecord(index));
  }
  public io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluent.PodRecordsNested<A> editFirstPodRecord() {
    if (podRecords.size() == 0) throw new RuntimeException("Can't edit first podRecords. The list is empty.");
    return setNewPodRecordLike(0, buildPodRecord(0));
  }
  public io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluent.PodRecordsNested<A> editLastPodRecord() {
    int index = podRecords.size() - 1;
    if (index < 0) throw new RuntimeException("Can't edit last podRecords. The list is empty.");
    return setNewPodRecordLike(index, buildPodRecord(index));
  }
  public io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluent.PodRecordsNested<A> editMatchingPodRecord(java.util.function.Predicate<io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder> predicate) {
    int index = -1;
    for (int i=0;i<podRecords.size();i++) { 
    if (predicate.test(podRecords.get(i))) {index = i; break;}
    } 
    if (index < 0) throw new RuntimeException("Can't edit matching podRecords. No match found.");
    return setNewPodRecordLike(index, buildPodRecord(index));
  }
  public java.lang.String getReason() {
    return this.reason;
  }
  public A withReason(java.lang.String reason) {
    this.reason=reason; return (A) this;
  }
  public java.lang.Boolean hasReason() {
    return this.reason != null;
  }
  
  /**
   * Method is deprecated. use withReason instead.
   */
  @java.lang.Deprecated
  public A withNewReason(java.lang.String arg0) {
    return (A)withReason(new String(arg0));
  }
  public java.lang.String getStartTime() {
    return this.startTime;
  }
  public A withStartTime(java.lang.String startTime) {
    this.startTime=startTime; return (A) this;
  }
  public java.lang.Boolean hasStartTime() {
    return this.startTime != null;
  }
  
  /**
   * Method is deprecated. use withStartTime instead.
   */
  @java.lang.Deprecated
  public A withNewStartTime(java.lang.String arg0) {
    return (A)withStartTime(new String(arg0));
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ExperimentStatusFluentImpl that = (ExperimentStatusFluentImpl) o;
    if (duration != null ? !duration.equals(that.duration) :that.duration != null) return false;
    if (endTime != null ? !endTime.equals(that.endTime) :that.endTime != null) return false;
    if (phase != null ? !phase.equals(that.phase) :that.phase != null) return false;
    if (podRecords != null ? !podRecords.equals(that.podRecords) :that.podRecords != null) return false;
    if (reason != null ? !reason.equals(that.reason) :that.reason != null) return false;
    if (startTime != null ? !startTime.equals(that.startTime) :that.startTime != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(duration,  endTime,  phase,  podRecords,  reason,  startTime,  super.hashCode());
  }
  public class PodRecordsNestedImpl<N> extends io.fabric8.chaosmesh.v1alpha1.PodStatusFluentImpl<io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluent.PodRecordsNested<N>> implements io.fabric8.chaosmesh.v1alpha1.ExperimentStatusFluent.PodRecordsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PodRecordsNestedImpl(java.lang.Integer index,io.fabric8.chaosmesh.v1alpha1.PodStatus item) {
      this.index = index;
      this.builder = new io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder(this, item);
    }
    PodRecordsNestedImpl() {
      this.index = -1;
      this.builder = new io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder(this);
    }
    io.fabric8.chaosmesh.v1alpha1.PodStatusBuilder builder;
    java.lang.Integer index;
    public N and() {
      return (N) ExperimentStatusFluentImpl.this.setToPodRecords(index,builder.build());
    }
    public N endPodRecord() {
      return and();
    }
    
  }
  
}
